# AutoTestStepModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**title** | **str** | Step name. | 
**description** | **str, none_type** | Detailed step description. It appears when the step is unfolded. | [optional] 
**steps** | [**[AutoTestStepModel], none_type**](AutoTestStepModel.md) | Includes a nested step inside another step. The maximum nesting level is 15. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


